@@ -8,6 +8,14 @@
 #include "pyobjc-unittest.h"
 
 #include <fcntl.h>
+#include <simd/simd.h>
+
+// LCOV_BR_EXCL_START
+// LCOV_EXCL_START
+
+NS_ASSUME_NONNULL_BEGIN
+
+#pragma clang diagnostic ignored "-Wunused-result"
 
 struct Struct1 {
     int    f1;
@@ -57,15 +65,8 @@ static struct Struct2 invokeHelper = {0, 0, {0, 0, 0, 0, 0}};
 BEGIN_UNITTEST(CheckNSInvoke)
 /* This is not a 'real' unittest, but is used to disable a number of
  * other tests (in objc.test.test_methods2) when NSInvocation isn't
- * working correctly (MacOS X at least upto 10.2.6).
- * [Panther previews also have this problem]
- *
- * Leopard is even worse, this test causes a crash of the interpreter when
- * running on PPC64.
+ * working correctly (MacOS X at least up to 10.2.6).
  */
-#ifdef __ppc64__
-ASSERT_EQUALS(0, 1, "%d");
-#endif
 
 PyObjCTest_NSInvoke* obj = [[PyObjCTest_NSInvoke alloc] init];
 NSInvocation*        inv;
@@ -93,6 +94,59 @@ ASSERT_EQUALS(invokeHelper.s[4], v1.s[4], "%d");
 
 END_UNITTEST
 
+/* Note: VectorSize and VectorAlign
+ *  (a) test the same set of types
+ *  (b) test all vector/matrix types found in system frameworks
+ *      that are wrapped in PyObjC.
+ */
+BEGIN_UNITTEST(VectorSize)
+ASSERT_EQUALS(sizeof(vector_uchar16), PyObjCRT_SizeOfType("<16C>"), "%d");
+ASSERT_EQUALS(sizeof(vector_short2), PyObjCRT_SizeOfType("<2s>"), "%d");
+ASSERT_EQUALS(sizeof(vector_ushort2), PyObjCRT_SizeOfType("<2S>"), "%d");
+ASSERT_EQUALS(sizeof(vector_ushort4), PyObjCRT_SizeOfType("<4S>"), "%d");
+ASSERT_EQUALS(sizeof(vector_int2), PyObjCRT_SizeOfType("<2i>"), "%d");
+ASSERT_EQUALS(sizeof(vector_uint3), PyObjCRT_SizeOfType("<3I>"), "%d");
+ASSERT_EQUALS(sizeof(vector_float2), PyObjCRT_SizeOfType("<2f>"), "%d");
+ASSERT_EQUALS(sizeof(vector_float3), PyObjCRT_SizeOfType("<3f>"), "%d");
+ASSERT_EQUALS(sizeof(vector_float4), PyObjCRT_SizeOfType("<4f>"), "%d");
+ASSERT_EQUALS(sizeof(vector_double2), PyObjCRT_SizeOfType("<2d>"), "%d");
+ASSERT_EQUALS(sizeof(vector_double3), PyObjCRT_SizeOfType("<3d>"), "%d");
+ASSERT_EQUALS(sizeof(vector_double4), PyObjCRT_SizeOfType("<4d>"), "%d");
+
+Py_ssize_t n = PyObjCRT_SizeOfType("<4,4di");
+FAIL_IF(n != -1);
+PyErr_Clear();
+
+n = PyObjCRT_SizeOfType("<d>");
+FAIL_IF(n != -1);
+PyErr_Clear();
+
+END_UNITTEST
+
+BEGIN_UNITTEST(VectorAlign)
+ASSERT_EQUALS(__alignof__(vector_uchar16), PyObjCRT_AlignOfType("<16C>"), "%d");
+ASSERT_EQUALS(__alignof__(vector_short2), PyObjCRT_AlignOfType("<2s>"), "%d");
+ASSERT_EQUALS(__alignof__(vector_ushort2), PyObjCRT_AlignOfType("<2S>"), "%d");
+ASSERT_EQUALS(__alignof__(vector_ushort4), PyObjCRT_AlignOfType("<4S>"), "%d");
+ASSERT_EQUALS(__alignof__(vector_int2), PyObjCRT_AlignOfType("<2i>"), "%d");
+ASSERT_EQUALS(__alignof__(vector_uint3), PyObjCRT_AlignOfType("<3I>"), "%d");
+ASSERT_EQUALS(__alignof__(vector_float2), PyObjCRT_AlignOfType("<2f>"), "%d");
+ASSERT_EQUALS(__alignof__(vector_float3), PyObjCRT_AlignOfType("<3f>"), "%d");
+ASSERT_EQUALS(__alignof__(vector_float4), PyObjCRT_AlignOfType("<4f>"), "%d");
+ASSERT_EQUALS(__alignof__(vector_double2), PyObjCRT_AlignOfType("<2d>"), "%d");
+ASSERT_EQUALS(__alignof__(vector_double3), PyObjCRT_AlignOfType("<3d>"), "%d");
+ASSERT_EQUALS(__alignof__(vector_double4), PyObjCRT_AlignOfType("<4d>"), "%d");
+
+Py_ssize_t n = PyObjCRT_AlignOfType("<4,4di");
+FAIL_IF(n != -1);
+PyErr_Clear();
+
+n = PyObjCRT_AlignOfType("<d>");
+FAIL_IF(n != -1);
+PyErr_Clear();
+
+END_UNITTEST
+
 BEGIN_UNITTEST(StructSize)
 
 ASSERT_EQUALS(sizeof(struct Struct1), PyObjCRT_SizeOfType(@encode(struct Struct1)), "%d");
@@ -406,13 +460,7 @@ END_UNITTEST
 
 BEGIN_UNITTEST(TestSizeOfBool)
 
-/* Code in libffi_support.m depends on this equality. */
-#if defined(__ppc__) || defined(__ppc64__)
-ASSERT_EQUALS(sizeof(bool), sizeof(int), "%d");
-
-#else
 ASSERT_EQUALS(sizeof(bool), sizeof(char), "%d");
-#endif
 
 END_UNITTEST
 
@@ -470,7 +518,7 @@ a = [NSMutableArray arrayWithObjects:d, nil];
 @try {
     v             = [a valueForKey:@"keyM"];
     haveException = 0;
-} @catch (NSObject* localException) {
+} @catch (NSObject* localException) { // LCOV_EXCL_LINE (see comment at start)
     v             = nil;
     haveException = 1;
 }
@@ -478,20 +526,23 @@ a = [NSMutableArray arrayWithObjects:d, nil];
 [p release];
 
 ASSERT(!haveException);
+ASSERT(v != nil);
 END_UNITTEST
 
 BEGIN_UNITTEST(PythonListAsNSArray)
 PyObject*       aList;
 NSMutableArray* array;
 NSArray*        array2;
+int             r;
 
 aList = Py_BuildValue("[iiiii]", 0, 1, 2, 3, 4);
 FAIL_IF(aList == NULL);
 
-array = PyObjC_PythonToId(aList);
+r = depythonify_python_object(aList, &array);
+FAIL_IF(r == -1);
 FAIL_IF(array == nil);
 
-/* Check lenght */
+/* Check length */
 ASSERT_EQUALS(5, [array count], "%d");
 
 /* Check basic element access */
@@ -546,14 +597,16 @@ BEGIN_UNITTEST(PythonTupleAsNSArray)
 PyObject* aTuple;
 NSArray*  array;
 NSArray*  array2;
+int       r;
 
 aTuple = Py_BuildValue("(iiiii)", 0, 1, 2, 3, 4);
 FAIL_IF(aTuple == NULL);
 
-array = PyObjC_PythonToId(aTuple);
+r = depythonify_python_object(aTuple, &array);
+FAIL_IF(r == -1);
 FAIL_IF(array == nil);
 
-/* Check lenght */
+/* Check length */
 ASSERT_EQUALS(5, [array count], "%d");
 
 /* Check basic element access */
@@ -589,11 +642,13 @@ PyObject*            aDictionary;
 NSMutableDictionary* dict;
 NSEnumerator*        iter;
 NSArray*             keys;
+int                  r;
 
 aDictionary = Py_BuildValue("{iiiiiiii}", 1, 2, 2, 4, 3, 6, 4, 8);
 FAIL_IF(aDictionary == NULL);
 
-dict = PyObjC_PythonToId(aDictionary);
+r = depythonify_python_object(aDictionary, &dict);
+FAIL_IF(r == -1);
 FAIL_IF(dict == nil);
 
 ASSERT_EQUALS(4, [dict count], "%d");
@@ -624,7 +679,7 @@ BEGIN_UNITTEST(NSLogging)
 /* This is a pretty lame test ...
  *
  * What this does is tests that the proxies of plain Python objects
- * can be logged. This used to be impossible upto (and including)
+ * can be logged. This used to be impossible up to (and including)
  * release 1.1!
  */
 PyObject* o = (PyObject*)(Py_BuildValue("i", 10)->ob_type);
@@ -633,7 +688,8 @@ int       fd;
 int       stderr_orig;
 int       r;
 
-value = PyObjC_PythonToId(o);
+r = depythonify_python_object(o, &value);
+FAIL_IF(r == -1);
 FAIL_IF(value == nil);
 
 fd = open("/dev/null", O_WRONLY);
@@ -814,8 +870,200 @@ long actual_align  = (long)__alignof__(NSDecimal);
 ASSERT_EQUALS(encoded_align, actual_align, "%ld");
 END_UNITTEST
 
+BEGIN_UNITTEST(MemView)
+PyObject* view = PyObjCMemView_New();
+
+ASSERT(view != NULL);
+ASSERT(PyObjCMemView_Check(view));
+ASSERT(!PyObjCMemView_Check(Py_True));
+
+Py_buffer* buf = PyObjCMemView_GetBuffer(view);
+ASSERT(buf);
+ASSERT(!buf->obj);
+ASSERT(!PyErr_Occurred());
+
+buf = PyObjCMemView_GetBuffer(Py_True);
+ASSERT(!buf);
+ASSERT(PyErr_Occurred());
+PyErr_Clear();
+
+PyObject* repr = PyObject_Repr(view);
+ASSERT(repr);
+ASSERT(PyObjC_is_ascii_string(repr, "objc.memview object"));
+
+Py_DECREF(view);
+END_UNITTEST
+
+BEGIN_UNITTEST(ReleasedBuffer)
+PyObject*         v;
+OCReleasedBuffer* buf;
+
+v = PyBytes_FromString("hello world\n");
+ASSERT(v);
+
+buf = [[OCReleasedBuffer alloc] initWithPythonBuffer:v writable:NO];
+ASSERT(buf);
+if (![buf buffer]) {
+    [buf release];
+    ASSERT(0);
+}
+
+if (strncmp([buf buffer], "hello", 5) != 0) {
+    [buf release];
+    ASSERT(0);
+}
+
+[buf release];
+
+buf = [[OCReleasedBuffer alloc] initWithPythonBuffer:v writable:YES];
+if (buf) {
+    [buf release];
+    ASSERT(!buf);
+}
+ASSERT(PyErr_Occurred());
+PyErr_Clear();
+
+v = PyByteArray_FromStringAndSize("hello", 5);
+ASSERT(v);
+buf = [[OCReleasedBuffer alloc] initWithPythonBuffer:v writable:NO];
+ASSERT(buf);
+if (![buf buffer]) {
+    Py_CLEAR(v);
+    [buf release];
+    ASSERT(0);
+}
+if (strncmp([buf buffer], "hello", 5) != 0) {
+    Py_CLEAR(v);
+    [buf release];
+    ASSERT(0);
+}
+
+[buf release];
+
+buf = [[OCReleasedBuffer alloc] initWithPythonBuffer:v writable:YES];
+ASSERT(buf);
+if (![buf buffer]) {
+    Py_CLEAR(v);
+    [buf release];
+    ASSERT(0);
+}
+if (strncmp([buf buffer], "hello", 5) != 0) {
+    Py_CLEAR(v);
+    [buf release];
+    ASSERT(0);
+}
+Py_CLEAR(v);
+[buf release];
+
+END_UNITTEST
+
+BEGIN_UNITTEST(AlwaysFails)
+ASSERT(0 == 1);
+END_UNITTEST
+
+BEGIN_UNITTEST(InvalidObjCPointer)
+
+/* Invalid type encoding */
+PyObject* p = PyObjCPointer_New(&p, "^{foo=");
+ASSERT(PyErr_Occurred());
+ASSERT(!p);
+PyErr_Clear();
+
+p = PyObjCPointer_New(&p, "{foo=");
+ASSERT(PyErr_Occurred());
+ASSERT(!p);
+PyErr_Clear();
+
+END_UNITTEST
+
+BEGIN_UNITTEST(InvalidRegistryUsage)
+PyObject* bytes = PyBytes_FromString("hello");
+if (bytes == NULL) {
+    return NULL;
+}
+
+int r = PyObjC_AddToRegistry(bytes, bytes, bytes, bytes);
+Py_DECREF(bytes);
+ASSERT(r == -1);
+
+PyErr_Clear();
+
+END_UNITTEST
+
+BEGIN_UNITTEST(BytesInterning)
+PyObject* b1;
+PyObject* b2;
+
+b1 = PyObjCBytes_InternFromString("hello");
+FAIL_IF(b1 == NULL);
+if (!PyBytes_Check(b1)) {
+    Py_DECREF(b1);
+    ASSERT(0);
+}
+ASSERT_EQUALS(strcmp(PyBytes_AsString(b1), "hello"), 0, "%d");
+
+b2 = PyObjCBytes_InternFromStringAndSize("hello world", 5);
+FAIL_IF(b2 == NULL);
+if (!PyBytes_Check(b2)) {
+    Py_DECREF(b2);
+    ASSERT(0);
+}
+
+ASSERT_EQUALS(b1, b2, "%p");
+
+Py_DECREF(b1);
+Py_DECREF(b2);
+
+END_UNITTEST
+
+BEGIN_UNITTEST(MethodSignatureString)
+PyObjCMethodSignature* sig = PyObjCMethodSignature_WithMetaData("@@:d", NULL, NO);
+FAIL_IF(sig == NULL);
+
+PyObject* repr = PyObject_Str((PyObject*)sig);
+Py_DECREF(sig);
+FAIL_IF(repr == NULL);
+if (!PyUnicode_Check(repr)) {
+    Py_DECREF(repr);
+    FAIL_IF(1);
+}
+Py_DECREF(repr);
+END_UNITTEST
+
+BEGIN_UNITTEST(ValidEncoding)
+FAIL_IF(!PyObjCRT_IsValidEncoding("@", 1));
+FAIL_IF(PyObjCRT_IsValidEncoding("@", 0));
+
+FAIL_IF(!PyObjCRT_IsValidEncoding("<23f>", 5));
+FAIL_IF(PyObjCRT_IsValidEncoding("<23f>", 3));
+FAIL_IF(PyObjCRT_IsValidEncoding("<23f>", 4));
+
+FAIL_IF(!PyObjCRT_IsValidEncoding("[23{a=ff}]", 10));
+FAIL_IF(PyObjCRT_IsValidEncoding("[23{a=ff}]", 9));
+FAIL_IF(PyObjCRT_IsValidEncoding("[23{a=ff}]", 8));
+FAIL_IF(PyObjCRT_IsValidEncoding("[23{a=ff}]", 5));
+FAIL_IF(PyObjCRT_IsValidEncoding("[23{a=ff}]", 3));
+
+FAIL_IF(!PyObjCRT_IsValidEncoding("{a=ff}", 6));
+FAIL_IF(PyObjCRT_IsValidEncoding("{a=ff}", 5));
+FAIL_IF(PyObjCRT_IsValidEncoding("{a=ff}", 4));
+FAIL_IF(PyObjCRT_IsValidEncoding("{a=ff}", 3));
+FAIL_IF(PyObjCRT_IsValidEncoding("{a=ff}", 2));
+FAIL_IF(PyObjCRT_IsValidEncoding("{a=ff}", 1));
+
+FAIL_IF(!PyObjCRT_IsValidEncoding("n^{a=i}", 7));
+FAIL_IF(PyObjCRT_IsValidEncoding("n^{a=i}", 5));
+FAIL_IF(PyObjCRT_IsValidEncoding("n^{a=i}", 2));
+FAIL_IF(PyObjCRT_IsValidEncoding("n^{a=i}", 1));
+
+FAIL_IF(PyObjCRT_IsValidEncoding("{a=\"f\"i}", 8));
+
+END_UNITTEST
+
 static PyMethodDef mod_methods[] = {TESTDEF(CheckNSInvoke),
 
+                                    TESTDEF(VectorSize),
+                                    TESTDEF(VectorAlign),
                                     TESTDEF(StructSize),
                                     TESTDEF(StructAlign),
                                     TESTDEF(FillStruct1),
@@ -843,6 +1091,14 @@ static PyMethodDef mod_methods[] = {TESTDEF(CheckNSInvoke),
                                     TESTDEF(UnicodeFunctions),
                                     TESTDEF(DecimalSize),
                                     TESTDEF(DecimalAlign),
+                                    TESTDEF(MemView),
+                                    TESTDEF(ReleasedBuffer),
+                                    TESTDEF(AlwaysFails),
+                                    TESTDEF(InvalidObjCPointer),
+                                    TESTDEF(InvalidRegistryUsage),
+                                    TESTDEF(BytesInterning),
+                                    TESTDEF(MethodSignatureString),
+                                    TESTDEF(ValidEncoding),
                                     {0, 0, 0, 0}};
 
 int
@@ -850,23 +1106,28 @@ PyObjC_init_ctests(PyObject* m)
 {
     PyObject* d = PyDict_New();
     if (d == NULL) {
-        return -1;
+        return -1; // LCOV_EXCL_LINE
     }
 
     PyMethodDef* cur;
     for (cur = mod_methods; cur->ml_name != NULL; cur++) {
         PyObject* meth = PyCFunction_NewEx(cur, NULL, NULL);
         if (meth == NULL) {
-            Py_DECREF(d);
-            return -1;
+            Py_DECREF(d); // LCOV_EXCL_LINE
+            return -1;    // LCOV_EXCL_LINE
         }
         if (PyDict_SetItemString(d, cur->ml_name, meth) < 0) {
-            Py_DECREF(d);
-            Py_DECREF(meth);
-            return -1;
+            Py_DECREF(d);    // LCOV_EXCL_LINE
+            Py_DECREF(meth); // LCOV_EXCL_LINE
+            return -1;       // LCOV_EXCL_LINE
         }
         Py_DECREF(meth);
     }
 
     return PyModule_AddObject(m, "_ctests", d);
 }
+
+// LCOV_BR_EXCL_STOP
+// LCOV_EXCL_STOP
+
+NS_ASSUME_NONNULL_END
