@@ -1,7 +1,7 @@
 """
 Wrappers for the "AVFoundation" framework on macOS.
 
-These wrappers don't include documentation, please check Apple's documention
+These wrappers don't include documentation, please check Apple's documentation
 for information on how to use this framework and PyObjC's documentation
 for general tips and tricks regarding the translation between Python
 and (Objective-)C frameworks
@@ -9,9 +9,14 @@ and (Objective-)C frameworks
 
 import os
 
-from pyobjc_setup import Extension, setup
+import sys
 
-VERSION = "6.2.2"
+sys.path.insert(0, os.path.dirname(__file__))
+
+
+from pyobjc_setup import Extension, setup  # noqa: E402
+
+VERSION = "10.3.2"
 
 setup(
     name="pyobjc-framework-AVFoundation",
@@ -41,6 +46,7 @@ setup(
     install_requires=[
         "pyobjc-core>=" + VERSION,
         "pyobjc-framework-CoreMedia>=" + VERSION,
+        "pyobjc-framework-CoreAudio>=" + VERSION,
         "pyobjc-framework-Cocoa>=" + VERSION,
         "pyobjc-framework-Quartz>=" + VERSION,
     ],
