@@ -1,19 +1,23 @@
 """
 Wrappers for the "AddressBook" framework on macOS. The Address Book is
-a centralized database for contact and other information for people. Appliations
+a centralized database for contact and other information for people. Applications
 that make use of the AddressBook framework all use the same database.
 
-These wrappers don't include documentation, please check Apple's documention
+These wrappers don't include documentation, please check Apple's documentation
 for information on how to use this framework and PyObjC's documentation
 for general tips and tricks regarding the translation between Python
 and (Objective-)C frameworks
 """
 
 import os
+import sys
 
-from pyobjc_setup import Extension, setup
+sys.path.insert(0, os.path.dirname(__file__))
 
-VERSION = "6.2.2"
+
+from pyobjc_setup import Extension, setup  # noqa: E402
+
+VERSION = "10.3.2"
 
 setup(
     name="pyobjc-framework-AddressBook",
