@@ -5,16 +5,23 @@ macOS.
 The CFNetwork framework provides a library of abstractions for networking
 protocols. The most interesting bits for Python programmers are the
 API's for working with proxy autoconfiguration and the API's for networking
-diagnotics.
+diagnostics.
 
-These wrappers don't include documentation, please check Apple's documention
+These wrappers don't include documentation, please check Apple's documentation
 for information on how to use this framework and PyObjC's documentation
 for general tips and tricks regarding the translation between Python
 and (Objective-)C frameworks
 """
-from pyobjc_setup import Extension, setup
 
-VERSION = "6.2.2"
+import os
+import sys
+
+sys.path.insert(0, os.path.dirname(__file__))
+
+
+from pyobjc_setup import Extension, setup  # noqa: E402
+
+VERSION = "10.3.2"
 
 setup(
     name="pyobjc-framework-CFNetwork",
