@@ -5,7 +5,13 @@ import socket
 import sys
 
 import CoreFoundation
-from PyObjCTools.TestSupport import TestCase, min_os_level, onlyIf
+from PyObjCTools.TestSupport import (
+    TestCase,
+    min_os_level,
+    skipUnless,
+    os_level_key,
+    os_release,
+)
 import objc
 
 from .test_cfsocket import onTheNetwork
@@ -99,6 +105,8 @@ class TestStream(TestCase):
         self.assertHasAttr(o, "domain")
         self.assertHasAttr(o, "error")
 
+        self.assertPickleRoundTrips(o)
+
     def testGetTypeID(self):
         v = CoreFoundation.CFReadStreamGetTypeID()
         self.assertIsInstance(v, int)
@@ -160,10 +168,7 @@ class TestStream(TestCase):
 
         self.assertResultIsCFRetained(CoreFoundation.CFReadStreamCreateWithFile)
         stream = CoreFoundation.CFReadStreamCreateWithFile(
-            None,
-            CoreFoundation.CFURLCreateWithString(
-                None, b"file:///etc/shells".decode("ascii"), None
-            ),
+            None, CoreFoundation.CFURLCreateWithString(None, "file:///etc/shells", None)
         )
         self.assertIsInstance(stream, CoreFoundation.CFReadStreamRef)
         r = CoreFoundation.CFReadStreamOpen(stream)
@@ -284,7 +289,7 @@ class TestStream(TestCase):
         stream = CoreFoundation.CFWriteStreamCreateWithFile(
             None,
             CoreFoundation.CFURLCreateWithString(
-                None, b"file:///tmp/pyobjc.test.txt".decode("ascii"), None
+                None, "file:///tmp/pyobjc.test.txt", None
             ),
         )
         self.assertIsInstance(stream, CoreFoundation.CFWriteStreamRef)
@@ -325,7 +330,6 @@ class TestStream(TestCase):
         os.unlink("/tmp/pyobjc.test.txt")
 
     def testStreamPair(self):
-
         self.assertArgIsOut(CoreFoundation.CFStreamCreateBoundPair, 1)
         self.assertArgIsOut(CoreFoundation.CFStreamCreateBoundPair, 2)
         readStream, writeStream = CoreFoundation.CFStreamCreateBoundPair(
@@ -344,7 +348,7 @@ class TestStream(TestCase):
 
         del readStream, writeStream
 
-    @onlyIf(onTheNetwork(), "Test requires a working Internet connection")
+    @skipUnless(onTheNetwork(), "Test requires a working Internet connection")
     def testSockets(self):
         with contextlib.closing(
             socket.socket(socket.AF_INET, socket.SOCK_STREAM)
@@ -417,6 +421,16 @@ class TestStream(TestCase):
         self.assertIsInstance(status, int)
         self.assertEqual(status, CoreFoundation.kCFStreamStatusNotOpen)
 
+    @skipUnless(
+        not (
+            os_level_key("10.13") <= os_level_key(os_release()) < os_level_key("10.15")
+        ),
+        "Crash on 10.13, 10.14??",
+    )
+    @skipUnless(
+        not (os_level_key("15.0") <= os_level_key(os_release()) < os_level_key("16.0")),
+        "Crash on macOS 15",
+    )
     def testReadSocketASync(self):
         rl = CoreFoundation.CFRunLoopGetCurrent()
 
@@ -476,6 +490,16 @@ class TestStream(TestCase):
         self.assertIs(state[0][2], data)
         self.assertEqual(state[0][1], CoreFoundation.kCFStreamEventHasBytesAvailable)
 
+    @skipUnless(
+        not (
+            os_level_key("10.13") <= os_level_key(os_release()) < os_level_key("10.15")
+        ),
+        "Crash on 10.13, 10.14??",
+    )
+    @skipUnless(
+        not (os_level_key("15.0") <= os_level_key(os_release()) < os_level_key("16.0")),
+        "Crash on macOS 15",
+    )
     def testWriteSocketAsync(self):
         rl = CoreFoundation.CFRunLoopGetCurrent()
 
