@@ -3,14 +3,21 @@ Wrappers for the "Collaboration" framework in macOS 10.5 or later. The
 Collaboration framework provides access to identities, and manages
 user interface elements for selecting identities.
 
-These wrappers don't include documentation, please check Apple's documention
+These wrappers don't include documentation, please check Apple's documentation
 for information on how to use this framework and PyObjC's documentation
 for general tips and tricks regarding the translation between Python
 and (Objective-)C frameworks
 """
-from pyobjc_setup import setup
 
-VERSION = "6.2.2"
+import os
+import sys
+
+sys.path.insert(0, os.path.dirname(__file__))
+
+
+from pyobjc_setup import setup  # noqa: E402
+
+VERSION = "10.3.2"
 
 setup(
     name="pyobjc-framework-Collaboration",
