@@ -1,17 +1,21 @@
 """
 Wrappers for the "CoreBluetooth" framework on macOS.
 
-These wrappers don't include documentation, please check Apple's documention
+These wrappers don't include documentation, please check Apple's documentation
 for information on how to use this framework and PyObjC's documentation
 for general tips and tricks regarding the translation between Python
 and (Objective-)C frameworks
 """
 
 import os
+import sys
 
-from pyobjc_setup import Extension, setup
+sys.path.insert(0, os.path.dirname(__file__))
 
-VERSION = "6.2.2"
+
+from pyobjc_setup import Extension, setup  # noqa: E402
+
+VERSION = "10.3.2"
 
 setup(
     name="pyobjc-framework-CoreBluetooth",
