@@ -3,16 +3,21 @@ Wrappers for the "CoreData" framework on macOS. The Core Data framework
 provides generalized and automated solutions to common tasks associated
 with object life-cycle and object graph management, including persistence.
 
-These wrappers don't include documentation, please check Apple's documention
+These wrappers don't include documentation, please check Apple's documentation
 for information on how to use this framework and PyObjC's documentation
 for general tips and tricks regarding the translation between Python
 and (Objective-)C frameworks
 """
+
 import os
+import sys
 
-from pyobjc_setup import setup, Extension
+sys.path.insert(0, os.path.dirname(__file__))
 
-VERSION = "6.2.2"
+
+from pyobjc_setup import setup, Extension  # noqa: E402
+
+VERSION = "10.3.2"
 
 setup(
     name="pyobjc-framework-CoreData",
