@@ -3,9 +3,16 @@ Deprecated wrappers for the "DictionaryServices" framework on macOS 10.5 or late
 
 Use package "CoreServices" instead.
 """
-from pyobjc_setup import setup
 
-VERSION = "6.2.2"
+import os
+import sys
+
+sys.path.insert(0, os.path.dirname(__file__))
+
+
+from pyobjc_setup import setup  # noqa: E402
+
+VERSION = "10.3.2"
 
 setup(
     name="pyobjc-framework-DictionaryServices",
