@@ -6,20 +6,26 @@ conditions in Cocoa programs.
 PyObjC also provides low-level debugging utilities beyond the core
 ExceptionHandling framework in the module ``PyObjCTools.Debugging``.
 
-These wrappers don't include documentation, please check Apple's documention
+These wrappers don't include documentation, please check Apple's documentation
 for information on how to use this framework and PyObjC's documentation
 for general tips and tricks regarding the translation between Python
 and (Objective-)C frameworks
 """
-from pyobjc_setup import setup
 
-VERSION = "6.2.2"
+import os
+import sys
+
+sys.path.insert(0, os.path.dirname(__file__))
+
+
+from pyobjc_setup import setup  # noqa: E402
+
+VERSION = "10.3.2"
 
 setup(
     name="pyobjc-framework-ExceptionHandling",
     description="Wrappers for the framework ExceptionHandling on macOS",
     packages=["PyObjCTools", "ExceptionHandling"],
-    namespace_packages=["PyObjCTools"],
     version=VERSION,
     install_requires=["pyobjc-core>=" + VERSION, "pyobjc-framework-Cocoa>=" + VERSION],
     long_description=__doc__,
