@@ -3,9 +3,16 @@ Deprecated wrappers for the "LaunchServices" framework on macOS.
 
 Use the "CoreServices" bindings instead.
 """
-from pyobjc_setup import setup
 
-VERSION = "6.2.2"
+import os
+import sys
+
+sys.path.insert(0, os.path.dirname(__file__))
+
+
+from pyobjc_setup import setup  # noqa: E402
+
+VERSION = "10.3.2"
 
 setup(
     name="pyobjc-framework-LaunchServices",
