@@ -8,13 +8,12 @@
 
 #import <ApplicationServices/ApplicationServices.h>
 
-#if PyObjC_BUILD_RELEASE >= 1005
 static PyObject*
 m_CGFontCopyTableTags(PyObject* self __attribute__((__unused__)), PyObject* args)
 {
     PyObject*  py_font;
-    CGFontRef  font;
-    CFArrayRef tags;
+    CGFontRef  font = NULL;
+    CFArrayRef tags = NULL;
 
     if (!PyArg_ParseTuple(args, "O", &py_font)) {
         return NULL;
@@ -205,6 +204,7 @@ m_CGWindowListCreateDescriptionFromArray(PyObject* self __attribute__((__unused_
     return rv;
 }
 
+#if defined(MAC_OS_X_VERSION_15_0) && MAC_OS_X_VERSION_MIN_REQUIRED < MAC_OS_X_VERSION_15_0
 static PyObject*
 m_CGWindowListCreateImageFromArray(PyObject* self __attribute__((__unused__)),
                                    PyObject* args)
@@ -238,8 +238,11 @@ m_CGWindowListCreateImageFromArray(PyObject* self __attribute__((__unused__)),
     CGImageRef image = NULL;
     Py_BEGIN_ALLOW_THREADS
         @try {
+#pragma clang diagnostic push
+#pragma clang diagnostic ignored "-Wdeprecated-declarations"
             image =
                 CGWindowListCreateImageFromArray(screenBounds, windowArray, imageOption);
+#pragma clang diagnostic pop
 
         } @catch (NSException* localException) {
             image = NULL;
@@ -262,7 +265,7 @@ m_CGWindowListCreateImageFromArray(PyObject* self __attribute__((__unused__)),
     CFRelease(image);
     return rv;
 }
-#endif /* PyObjC_BUILD_RELEASE >= 1005*/
+#endif /* defined(MAC_OS_X_VERSION_15_0) && MAC_OS_X_VERSION_MIN_REQUIRED < MAC_OS_X_VERSION_15_0 */
 
 static PyObject*
 m_CGBitmapContextCreate(PyObject* self __attribute__((__unused__)), PyObject* args)
@@ -275,13 +278,13 @@ m_CGBitmapContextCreate(PyObject* self __attribute__((__unused__)), PyObject* ar
     PyObject* py_colorSpace;
     PyObject* py_bitmapInfo;
 
-    void*           data;
     size_t          width;
     size_t          height;
     size_t          bitsPerComponent;
     size_t          bytesPerRow;
     CGColorSpaceRef colorSpace;
     CGBitmapInfo    bitmapInfo;
+    Py_buffer       view;
 
     if (!PyArg_ParseTuple(args, "OOOOOOO", &py_data, &py_width, &py_height,
                           &py_bitsPerComponent, &py_bytesPerRow, &py_colorSpace,
@@ -310,30 +313,24 @@ m_CGBitmapContextCreate(PyObject* self __attribute__((__unused__)), PyObject* ar
     }
 
     if (py_data == Py_None) {
-        data = NULL;
+        /* pass */
 
     } else if (PyUnicode_Check(py_data)) {
         PyErr_SetString(PyExc_TypeError, "Cannot use Unicode as backing store");
         return NULL;
 
     } else {
-        Py_ssize_t size;
-
-#pragma clang diagnostic push
-#pragma clang diagnostic ignored "-Wdeprecated-declarations"
-
-        if (PyObject_AsWriteBuffer(py_data, &data, &size) == -1) {
+        if (PyObject_GetBuffer(py_data, &view, PyBUF_CONTIG) == -1) {
             return NULL;
         }
-
-#pragma clang diagnostic pop
     }
 
     CGContextRef ctx = NULL;
     Py_BEGIN_ALLOW_THREADS
         @try {
-            ctx = CGBitmapContextCreate(data, width, height, bitsPerComponent,
-                                        bytesPerRow, colorSpace, bitmapInfo);
+            ctx = CGBitmapContextCreate(py_data == Py_None ? NULL : view.buf, width,
+                                        height, bitsPerComponent, bytesPerRow, colorSpace,
+                                        bitmapInfo);
 
         } @catch (NSException* localException) {
             ctx = NULL;
@@ -341,6 +338,13 @@ m_CGBitmapContextCreate(PyObject* self __attribute__((__unused__)), PyObject* ar
         }
     Py_END_ALLOW_THREADS
 
+    if (py_data != Py_None) {
+        /* This is not safe in general, but there is no way to keep the
+         * buffer alive until after the bitmap context is deallocated.
+         */
+        PyBuffer_Release(&view);
+    }
+
     if (ctx == NULL && PyErr_Occurred()) {
         return NULL;
     }
@@ -355,11 +359,11 @@ m_CGBitmapContextCreate(PyObject* self __attribute__((__unused__)), PyObject* ar
     return rv;
 }
 
-#if PyObjC_BUILD_RELEASE >= 1006
 static void
 m_releasecallback(void* releaseInfo, void* data)
 {
     PyObject* py_data = (PyObject*)releaseInfo;
+    PyObject* view;
 
     PyGILState_STATE state = PyGILState_Ensure();
 
@@ -370,6 +374,9 @@ m_releasecallback(void* releaseInfo, void* data)
         Py_XDECREF(r);
     }
 
+    view = PyTuple_GetItem(py_data, 3);
+    PyBuffer_Release(PyObjCMemView_GetBuffer(view));
+
     Py_DECREF(py_data);
 
     if (PyErr_Occurred()) {
@@ -378,7 +385,6 @@ m_releasecallback(void* releaseInfo, void* data)
     PyGILState_Release(state);
 }
 
-WEAK_LINKED_NAME_10_6(CGBitmapContextCreateWithData)
 static PyObject*
 m_CGBitmapContextCreateWithData(PyObject* self __attribute__((__unused__)),
                                 PyObject* args)
@@ -393,7 +399,7 @@ m_CGBitmapContextCreateWithData(PyObject* self __attribute__((__unused__)),
     PyObject* py_releaseCallback;
     PyObject* py_releaseInfo;
 
-    void*           data;
+    PyObject*       view = NULL;
     size_t          width;
     size_t          height;
     size_t          bitsPerComponent;
@@ -428,24 +434,26 @@ m_CGBitmapContextCreateWithData(PyObject* self __attribute__((__unused__)),
     }
 
     if (py_data == Py_None) {
-        data = NULL;
+        /* pass */
 
     } else if (PyUnicode_Check(py_data)) {
         PyErr_SetString(PyExc_TypeError, "Cannot use Unicode as backing store");
         return NULL;
 
     } else {
-        Py_ssize_t size;
+        view = PyObjCMemView_New();
+        if (view == NULL) {
+            return NULL;
+        }
 
-#pragma clang diagnostic push
-#pragma clang diagnostic ignored "-Wdeprecated-declarations"
-        if (PyObject_AsWriteBuffer(py_data, &data, &size) == -1) {
+        if (PyObject_GetBuffer(py_data, PyObjCMemView_GetBuffer(view), PyBUF_CONTIG)
+            == -1) {
+            Py_DECREF(view);
             return NULL;
         }
-#pragma clang diagnostic pop
     }
 
-    PyObject* releaseInfo = PyTuple_New(3);
+    PyObject* releaseInfo = PyTuple_New(4);
     if (releaseInfo == NULL) {
         return NULL;
     }
@@ -455,13 +463,15 @@ m_CGBitmapContextCreateWithData(PyObject* self __attribute__((__unused__)),
     Py_INCREF(py_releaseInfo);
     PyTuple_SET_ITEM(releaseInfo, 2, py_data);
     Py_INCREF(py_data);
+    PyTuple_SET_ITEM(releaseInfo, 3, view);
 
     CGContextRef ctx = NULL;
     Py_BEGIN_ALLOW_THREADS
         @try {
-            ctx = USE_10_6(CGBitmapContextCreateWithData)(
-                data, width, height, bitsPerComponent, bytesPerRow, colorSpace,
-                bitmapInfo, m_releasecallback, releaseInfo);
+            ctx = CGBitmapContextCreateWithData(
+                view ? PyObjCMemView_GetBuffer(view)->buf : NULL, width, height,
+                bitsPerComponent, bytesPerRow, colorSpace, bitmapInfo, m_releasecallback,
+                releaseInfo);
 
         } @catch (NSException* localException) {
             ctx = NULL;
@@ -470,11 +480,13 @@ m_CGBitmapContextCreateWithData(PyObject* self __attribute__((__unused__)),
     Py_END_ALLOW_THREADS
 
     if (ctx == NULL && PyErr_Occurred()) {
+        PyBuffer_Release(PyObjCMemView_GetBuffer(view));
         Py_DECREF(releaseInfo);
         return NULL;
     }
 
     if (ctx == NULL) {
+        PyBuffer_Release(PyObjCMemView_GetBuffer(view));
         Py_DECREF(releaseInfo);
         Py_INCREF(Py_None);
         return Py_None;
@@ -484,7 +496,6 @@ m_CGBitmapContextCreateWithData(PyObject* self __attribute__((__unused__)),
     CFRelease(ctx);
     return rv;
 }
-#endif
 
 static PyObject*
 m_CGPDFObjectGetValue(PyObject* self __attribute__((__unused__)), PyObject* args)
@@ -609,19 +620,17 @@ m_CGPDFObjectGetValue(PyObject* self __attribute__((__unused__)), PyObject* args
 }
 
 static PyMethodDef mod_methods[] = {
-#if PyObjC_BUILD_RELEASE >= 1005
     {"CGFontCopyTableTags", (PyCFunction)m_CGFontCopyTableTags, METH_VARARGS, NULL},
     {"CGWindowListCreate", (PyCFunction)m_CGWindowListCreate, METH_VARARGS, NULL},
     {"CGWindowListCreateDescriptionFromArray",
      (PyCFunction)m_CGWindowListCreateDescriptionFromArray, METH_VARARGS, NULL},
+#if defined(MAC_OS_X_VERSION_15_0) && MAC_OS_X_VERSION_MIN_REQUIRED < MAC_OS_X_VERSION_15_0
     {"CGWindowListCreateImageFromArray", (PyCFunction)m_CGWindowListCreateImageFromArray,
      METH_VARARGS, NULL},
-#endif /* PyObjC_BUILD_RELEASE >= 1005 */
+#endif /* defined(MAC_OS_X_VERSION_15_0) && MAC_OS_X_VERSION_MIN_REQUIRED < MAC_OS_X_VERSION_15_0 */
     {"CGBitmapContextCreate", (PyCFunction)m_CGBitmapContextCreate, METH_VARARGS, NULL},
-#if PyObjC_BUILD_RELEASE >= 1006
     {"CGBitmapContextCreateWithData", (PyCFunction)m_CGBitmapContextCreateWithData,
      METH_VARARGS, NULL},
-#endif
     {"CGPDFObjectGetValue", (PyCFunction)m_CGPDFObjectGetValue, METH_VARARGS, NULL},
 
     {
@@ -630,52 +639,19 @@ static PyMethodDef mod_methods[] = {
         0,
     }};
 
-PyObjC_MODULE_INIT(_coregraphics)
-{
-    PyObject* m = PyObjC_MODULE_CREATE(_coregraphics);
-    if (!m)
-        PyObjC_INITERROR();
+static struct PyModuleDef mod_module = {
+    PyModuleDef_HEAD_INIT, "_coregraphics", NULL, 0, mod_methods, NULL, NULL, NULL, NULL};
 
-#if PyObjC_BUILD_RELEASE >= 1005
-    PyObject* d = PyModule_GetDict(m);
-    if (!d)
-        PyObjC_INITERROR();
-#endif
+PyObject* PyInit__coregraphics(void);
+
+PyObject* __attribute__((__visibility__("default"))) PyInit__coregraphics(void)
+{
+    PyObject* m = PyModule_Create(&mod_module);
+    if (!m)
+        return NULL;
 
     if (PyObjC_ImportAPI(m) < 0)
-        PyObjC_INITERROR();
+        return NULL;
 
-#if PyObjC_BUILD_RELEASE >= 1005                                                         \
-    && (MAC_OS_X_VERSION_MIN_REQUIRED < MAC_OS_X_VERSION_10_5)
-    if (CGFontCopyTableTags == NULL) {
-        if (PyDict_DelItemString(d, "CGFontCopyTableTags") < 0) {
-            PyObjC_INITERROR();
-        }
-    }
-
-    if (CGWindowListCreate == NULL) {
-        if (PyDict_DelItemString(d, "CGWindowListCreate") < 0) {
-            PyObjC_INITERROR();
-        }
-    }
-
-    if (CGWindowListCreateDescriptionFromArray == NULL) {
-        if (PyDict_DelItemString(d, "CGWindowListCreateDescriptionFromArray") < 0) {
-            PyObjC_INITERROR();
-        }
-    }
-
-    if (CGWindowListCreateImageFromArray == NULL) {
-        if (PyDict_DelItemString(d, "CGWindowListCreateImageFromArray") < 0) {
-            PyObjC_INITERROR();
-        }
-    }
-#endif
-
-#if (PyObjC_BUILD_RELEASE >= 1006)                                                       \
-    && (MAC_OS_X_VERSION_MIN_REQUIRED < MAC_OS_X_VERSION_10_6)
-    CHECK_WEAK_LINK_10_6(m, CGBitmapContextCreateWithData);
-#endif
-
-    PyObjC_INITDONE();
+    return m;
 }
