@@ -1,4 +1,6 @@
+#ifndef PyObjC_GIL_DISABLED
 #define Py_LIMITED_API 0x03060000
+#endif
 #define PY_SSIZE_T_CLEAN
 #include "Python.h"
 #include "pyobjc-api.h"
@@ -10,8 +12,10 @@
  * because the functions are inline functions and hence will
  * be available on all macOS versions once compiled.
  */
+#if PyObjC_BUILD_RELEASE >= 1013
 #pragma clang diagnostic push
 #pragma clang diagnostic ignored "-Wunguarded-availability"
+#endif
 
 static PyObjC_function_map function_map[] = {
     {"SSCenteredRectInRect", (PyObjC_Function_Pointer)&SSCenteredRectInRect},
@@ -21,23 +25,30 @@ static PyObjC_function_map function_map[] = {
      (PyObjC_Function_Pointer)&SSRandomPointForSizeWithinRect},
     {0, 0}};
 
+#if PyObjC_BUILD_RELEASE >= 1013
 #pragma clang diagnostic pop
+#endif
 
 static PyMethodDef mod_methods[] = {
     {0, 0, 0, 0} /* sentinel */
 };
 
-PyObjC_MODULE_INIT(_inlines)
+static struct PyModuleDef mod_module = {
+    PyModuleDef_HEAD_INIT, "_inlines", NULL, 0, mod_methods, NULL, NULL, NULL, NULL};
+
+PyObject* PyInit__inlines(void);
+
+PyObject* __attribute__((__visibility__("default"))) PyInit__inlines(void)
 {
-    PyObject* m = PyObjC_MODULE_CREATE(_inlines);
+    PyObject* m = PyModule_Create(&mod_module);
     if (!m) {
-        PyObjC_INITERROR();
+        return NULL;
     }
 
     if (PyModule_AddObject(m, "_inline_list_", PyObjC_CreateInlineTab(function_map))
         < 0) {
-        PyObjC_INITERROR();
+        return NULL;
     }
 
-    PyObjC_INITDONE();
+    return m;
 }
