@@ -1,16 +1,23 @@
 """
 Wrappers for framework 'ServiceManagement' on macOS 10.6. This framework
-provides an interface to the system services subsystem, which basicly means
+provides an interface to the system services subsystem, which basically means
 a this provides a secure and object-oriented interface from launchd.
 
-These wrappers don't include documentation, please check Apple's documention
+These wrappers don't include documentation, please check Apple's documentation
 for information on how to use this framework and PyObjC's documentation
 for general tips and tricks regarding the translation between Python
 and (Objective-)C frameworks
 """
-from pyobjc_setup import setup
 
-VERSION = "6.2.2"
+import os
+import sys
+
+sys.path.insert(0, os.path.dirname(__file__))
+
+
+from pyobjc_setup import setup  # noqa: E402
+
+VERSION = "10.3.2"
 
 setup(
     name="pyobjc-framework-ServiceManagement",
