@@ -1,4 +1,6 @@
+#ifndef PyObjC_GIL_DISABLED
 #define Py_LIMITED_API 0x03060000
+#endif
 #define PY_SSIZE_T_CLEAN
 #include "Python.h"
 #include "pyobjc-api.h"
@@ -15,13 +17,21 @@ static PyMethodDef mod_methods[] = {
 };
 
 /* Python glue */
-PyObjC_MODULE_INIT(_StoreKit)
+static struct PyModuleDef mod_module = {
+    PyModuleDef_HEAD_INIT, "_StoreKit", NULL, 0, mod_methods, NULL, NULL, NULL, NULL};
+
+PyObject* PyInit__StoreKit(void);
+
+PyObject* __attribute__((__visibility__("default"))) PyInit__StoreKit(void)
 {
     PyObject* m;
-    m = PyObjC_MODULE_CREATE(_StoreKit) if (!m) { PyObjC_INITERROR(); }
+    m = PyModule_Create(&mod_module);
+    if (!m) {
+        return NULL;
+    }
 
     if (PyObjC_ImportAPI(m) == -1)
-        PyObjC_INITERROR();
+        return NULL;
 
-    PyObjC_INITDONE();
+    return m;
 }
